==> AmaterasUML_1.3.1.zip: src/net/java/amateras/uml/classdiagram/model/InterfaceModel.java <==
package net.java.amateras.uml.classdiagram.model;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import net.java.amateras.uml.UMLPlugin;
import net.java.amateras.uml.model.AbstractUMLEntityModel;
import net.java.amateras.uml.model.EntityModel;
import net.java.amateras.uml.model.ICloneableModel;

import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.ui.views.properties.ColorPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

/**
 * C^[tF[XfIuWFNgB
 * 
 * @author Naoki Takezoe
 */
public class InterfaceModel extends AbstractUMLEntityModel implements
		EntityModel, ICloneableModel {

	public static final String P_NAME = "_class_name";

	private String name = "";

	private String stereoType = "";

	private static int number = 1;

	public static final String P_ABSTRACT = "_abstract";

	private static final String P_ATTRIBUTES = "_attrs";

	private static final String P_OPERATIONS = "_operations";

	public InterfaceModel() {
		setName("Interface" + number);
		number++;
	}

	public void setName(String interfaceName) {
		String oldName = this.name;
		this.name = interfaceName;
		firePropertyChange(P_NAME, oldName, interfaceName);
	}

	public String getName() {
		return this.name;
	}

	public IPropertyDescriptor[] getPropertyDescriptors() {
		return new IPropertyDescriptor[] {
				new TextPropertyDescriptor(StereoTypeModel.P_STEREO_TYPE,
						UMLPlugin.getDefault().getResourceString(
								"property.stereoType")),
				new TextPropertyDescriptor(P_NAME, UMLPlugin.getDefault()
						.getResourceString("property.name")),
				new ColorPropertyDescriptor(P_BACKGROUND_COLOR, UMLPlugin
						.getDefault().getResourceString("property.background")),
				new PropertyDescriptor(P_ATTRIBUTES, UMLPlugin.getDefault()
						.getResourceString("property.attributes")),
				new PropertyDescriptor(P_OPERATIONS, UMLPlugin.getDefault()
						.getResourceString("property.operations")) };
	}

	public Object getPropertyValue(Object id) {
		if (id.equals(StereoTypeModel.P_STEREO_TYPE)) {
			return getStereoType();
		} else if (id.equals(P_NAME)) {
			return getName();
		} else if (id.equals(P_ATTRIBUTES)) {
			List rv = new ArrayList();
			for (Iterator iter = getChildren().iterator(); iter.hasNext();) {
				Object element = (Object) iter.next();
				if (element instanceof AttributeModel) {
					rv.add(element);
				}
			}
			return new ListPropertyWrapper(rv);
		} else if (id.equals(P_OPERATIONS)) {
			List rv = new ArrayList();
			for (Iterator iter = getChildren().iterator(); iter.hasNext();) {
				Object element = (Object) iter.next();
				if (element instanceof OperationModel) {
					rv.add(element);
				}
			}
			return new ListPropertyWrapper(rv);
		}
		return super.getPropertyValue(id);
	}

	public boolean isPropertySet(Object id) {
		if (id.equals(StereoTypeModel.P_STEREO_TYPE)) {
			return true;
		} else if (id.equals(P_NAME)) {
			return true;
		}
		return super.isPropertySet(id);
	}

	public void setPropertyValue(Object id, Object value) {
		if (id.equals(StereoTypeModel.P_STEREO_TYPE)) {
			setStereoType((String) value);
		} else if (id.equals(P_NAME)) {
			setName((String) value);
		}
		super.setPropertyValue(id, value);
	}

	public String toString() {
		return getName();
	}

	public String getStereoType() {
		return stereoType == null ? "" : stereoType;
	}

	public void setStereoType(String stereoType) {
		this.stereoType = stereoType;
		firePropertyChange(StereoTypeModel.P_STEREO_TYPE, null, stereoType);
	}

	public Object clone() {
		InterfaceModel newModel = new InterfaceModel();
		
		newModel.setBackgroundColor(getBackgroundColor().getRGB());
		newModel.setConstraint(new Rectangle(getConstraint()));
		newModel.setForegroundColor(getForegroundColor().getRGB());
		newModel.setName(getName());
		newModel.setParent(getParent());
		newModel.setShowIcon(isShowIcon());
		newModel.setStereoType(getStereoType());
		
		List children = getChildren();
		for(int i=0;i<children.size();i++){
			Object child = children.get(i);
			if(child instanceof AttributeModel){
				newModel.addChild((AttributeModel) ((AttributeModel)child).clone());
			} else if(child instanceof OperationModel){
				newModel.addChild((OperationModel) ((OperationModel)child).clone());
			}
		}
		
		return newModel;
	}
	
}

==> AmaterasUML_1.3.2.zip: src/net/java/amateras/uml/classdiagram/model/InterfaceModel.java <==
package net.java.amateras.uml.classdiagram.model;

import org.eclipse.draw2d.geometry.Rectangle;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * Class model that contains the data of a class shown in class diagram. 
 * 
 * @author Naoki Takezoe
 */
public class InterfaceModel extends CommonEntityModel {

	private static int number = 1;

	public InterfaceModel() {
		setName("Interface" + number);
		number++;
	}

	public Object getPropertyValue(Object id) {
		if (id.equals(CommonEntityModel.P_ATTRIBUTES)) {
			List rv = new ArrayList();
			for (Iterator iter = getChildren().iterator(); iter.hasNext();) {
				Object element = (Object) iter.next();
				if (element instanceof AttributeModel) {
					AttributeModel attribute = (AttributeModel) element;
					attribute.setVisibility(Visibility.PUBLIC);
					rv.add(element);
				}
			}
			return new ListPropertyWrapper(rv);
		} else if (id.equals(CommonEntityModel.P_OPERATIONS)) {
			List rv = new ArrayList();
			for (Iterator iter = getChildren().iterator(); iter.hasNext();) {
				Object element = (Object) iter.next();
				if (element instanceof OperationModel) {
					OperationModel operation = (OperationModel) element;
					operation.setVisibility(Visibility.PUBLIC);
					rv.add(element);
				}
			}
			return new ListPropertyWrapper(rv);
		}
		return super.getPropertyValue(id);
	}

	public void setPropertyValue(Object id, Object value) {
		if (id.equals(StereoTypeModel.P_STEREO_TYPE)) {
			setStereoType((String) value);
		} else if (id.equals(P_ENTITY_NAME)) {
			setName((String) value);
		}
		super.setPropertyValue(id, value);
	}

	/**
	 * Clone this object. TODO, duplicated code with InterfaceModel.clone(), be careful to override clone!
	 *@deprecated 
	 */
	public Object clone() {
		InterfaceModel newModel = new InterfaceModel();

		newModel.setBackgroundColor(getBackgroundColor().getRGB());
		newModel.setConstraint(new Rectangle(getConstraint()));
		newModel.setForegroundColor(getForegroundColor().getRGB());
		newModel.setName(getName());
		newModel.setSimpleName(getSimpleName());
		newModel.setParent(getParent());
		newModel.setShowIcon(isShowIcon());
		newModel.setStereoType(getStereoType());

		List children = getChildren();
		for (int i = 0; i < children.size(); i++) {
			Object child = children.get(i);
			if (child instanceof AttributeModel) {
				newModel.addChild((AttributeModel) ((AttributeModel) child).clone());
			} else if (child instanceof OperationModel) {
				newModel.addChild((OperationModel) ((OperationModel) child).clone());
			}
		}

		return newModel;
	}
}
